@@ -1,5 +1,5 @@
 # Interpreted GRASS 6 interface functions
-# Copyright (c) 2005-7 Roger S. Bivand
+# Copyright (c) 2005-8 Roger S. Bivand
 #
 readVECT6 <- function(vname, type=NULL, remove.duplicates=TRUE, ignore.stderr = FALSE, with_prj=TRUE, with_c=FALSE) {
 
@@ -41,7 +41,8 @@ readVECT6 <- function(vname, type=NULL, remove.duplicates=TRUE, ignore.stderr =
 
 	res <- readOGR(dsn=rtmpfl1, layer=shname, verbose=!ignore.stderr)
 
-	unlink(paste(rtmpfl1, list.files(rtmpfl1, pattern=shname), 
+	if (.Platform$OS.type != "windows") 
+            unlink(paste(rtmpfl1, list.files(rtmpfl1, pattern=shname), 
 		sep=.Platform$file.sep))
 	if (remove.duplicates && type != "point") {
 		dups <- duplicated(slot(res, "data"))
@@ -193,7 +194,8 @@ writeVECT6 <- function(SDF, vname, #factor2char = TRUE,
 
 	tull <- ifelse(.Platform$OS.type == "windows", system(cmd), 
 		system(cmd, ignore.stderr=ignore.stderr))
-	unlink(paste(rtmpfl1, list.files(rtmpfl1, pattern=shname), 
+	if (.Platform$OS.type != "windows") 
+            unlink(paste(rtmpfl1, list.files(rtmpfl1, pattern=shname), 
 		sep=.Platform$file.sep))
 
 }
@@ -435,5 +437,26 @@ vect2neigh <- function(vname, ID=NULL, ignore.stderr = FALSE) {
 	res
 }
 
+cygwin_clean_temp <- function(verbose=TRUE, ignore.stderr = FALSE) {
+	if (Sys.getenv("OSTYPE") != "cygwin") stop("this hack just for cygwin")
+	pid <- as.integer(round(runif(1, 1, 1000)))
+	cmd <- paste(paste("g.tempfile", .addexe(), sep=""),
+                    " pid=", pid, sep="")
+
+	gtmpfl1 <- dirname(ifelse(.Platform$OS.type == "windows", 
+		system(cmd, intern=TRUE), system(cmd, 
+		intern=TRUE, ignore.stderr=ignore.stderr)))
+	rtmpfl1 <- ifelse(.Platform$OS.type == "windows" &&
+                (Sys.getenv("OSTYPE") == "cygwin"), 
+		system(paste("cygpath -w", gtmpfl1, sep=" "), intern=TRUE), 
+		gtmpfl1)
+	flst <- list.files(rtmpfl1)
+	for (i in flst) {
+		f <- paste(rtmpfl1, i, sep="\\")
+		x <- file.remove(f)
+		if (verbose) cat(f, x, "\n")
+	}
+	invisible(flst)
+}
 
 
